@@ -2,29 +2,32 @@
 ## Testing a simple 10-variant gene on both the X chrom and autosome
 ## Authors: Dan Schaid and Jason Sinnwell
 ## Created: 19-AUG-2013
-## Updated: 11/7/2013
+## Updated: 9/8/2025
 
-## alternatively:
-require(kinship2)
-require(pedgene)
+devel=FALSE
+if(devel) {
+  .libPaths(c("/projects/bsi/pharmacogenetics/s212953.SchaidMethods/PedGene/Build/gitbranch/renv/library/R-4.4/x86_64-pc-linux-gnu/",.libPaths()))
+  library(CompQuadForm)
+  library(Pedixplorer)
+  library(survey)
+  dir="../"
+  rfiles <- list.files("../R/", pattern="*.R", full=TRUE)
+  for(rf in rfiles) source(rf)
+  dfiles <- list.files(path=paste0(dir,"/data/"), pattern="*.RData$")
+  for(d in dfiles) load(paste0(dir, "/data/",d))
 
-data(example.ped)
-data(example.geno)
-data(example.map)
-
-
-if(0) {
-## delete above line to look at pedigrees
-## quick look at the 3 pedigrees
-  pedall <- with(example.ped, pedigree(famid=ped, id=person, dadid=father,
-                momid=mother, sex=sex, affected=ifelse(is.na(trait), 0, trait)))
+} else {
+  ## alternatively:
   
-  plot(pedall[1])
-  plot(pedall[2])
-  plot(pedall[3])
+  require(pedgene)
+
+  data(example.ped)
+  data(example.geno)
+  data(example.map)
 }
 
 
+
 ## simple tests of two genes (10 variants each)
 ## the genes are same variants, just on chroms 1 and X
 pg.m2 <- pedgene(example.ped, example.geno, example.map, male.dose=2)
