@@ -1,13 +1,16 @@
 
 ## Expanded test script for pedgene package
 devel=FALSE
+
 if(devel) {
-  rfiles <- list.files(path="../R/", pattern="*.R$")
-  for(f in rfiles) source(paste("../R/",f,sep=""))
-  dfiles <- list.files(path="../data/", pattern="*.RData$")
-  for(d in dfiles) load(paste("../data/",d,sep=""))
-  library(kinship2)
+  dir=".."
+  rfiles <- list.files(path=paste0(dir, "/R/"), pattern="*.R$")
+  for(f in rfiles) source(paste0(dir,"/R/",f))
+  dfiles <- list.files(path=paste0(dir,"/data/"), pattern="*.RData$")
+  for(d in dfiles) load(paste0(dir, "/data/",d))
+#  library(kinship2)
   library(survey)
+  library(Pedixplorer)
 } else {
   
   require(pedgene)
@@ -37,12 +40,14 @@ pg.out.m2 <- pedgene(ped=example.ped, geno=example.geno, map=example.map, male.d
 print.pedgene(pg.out.m2,digits=3)
 
 ## with twins
-example.ped[10,"sex"] <- 2
-#example.relation[2,4] <- 1
+example.pedt <- example.ped
+example.relationt <- example.relation
+example.pedt[example.pedt$person==7,"sex"] <- 1
+example.relationt[1,"code"] <- 1
 #colnames(example.relation) <- c("ped","id1","id2", "code")
 #data(example.relation)
 #example.relation
-pg.out.m2.twins <- pedgene(ped=example.ped, geno=example.geno, relation=example.relation,
+pg.out.m2.twins <- pedgene(ped=example.pedt, geno=example.geno, relation=example.relationt,
            map=example.map, male.dose=2,  weights.mb=TRUE, checkpeds=TRUE)
 
 # summary/print and plot methods for this object
@@ -114,6 +119,7 @@ example2.geno <- rbind(example.geno[1,],example.geno)
 pg.out <- pedgene(ped=example.ped, geno=example2.geno, map=example.map, male.dose=2,
                      weights.mb=TRUE,checkpeds=TRUE, method=NA)
 warnings()
+print(pg.out)
 example2.geno[1,1:2] <- c(10,5)
 pg.out <- pedgene(ped=example.ped, geno=example2.geno, map=example.map, male.dose=2,
                      weights.mb=TRUE,checkpeds=TRUE)
@@ -164,7 +170,7 @@ for(k in 2:10) {
 ## Add two genes: one with 1 variant. Another with no markers with variance
 genobig <- cbind(genobig, example.geno[,6], rep(1, nrow(example.geno)), rep(2, nrow(example.geno)))
 mapbig <- rbind(mapbig, c(10, "onevar"), c(11,"novar"), c(11, "novar"))
-                
+## should get warning that one gene has no markers with variants                
 
 pgbig.m2 <- pedgene(example.ped, genobig, mapbig, male.dose=2, acc.davies=1e-4)
 pgbig.m1 <- pedgene(example.ped, genobig, mapbig, male.dose=1, acc.davies=1e-4)
